@@ -2,12 +2,14 @@ from __future__ import annotations
 
 import shutil
 import subprocess
+from contextlib import suppress
 from pathlib import Path
 
 import pytest
 from flaky import flaky
 
 from virtualenv.discovery.py_info import PythonInfo
+from virtualenv.info import fs_supports_symlink
 from virtualenv.run import cli_run
 
 HERE = Path(__file__).parent
@@ -25,7 +27,7 @@ def zipapp_build_env(tmp_path_factory):
         # prefer CPython as builder as pypy is slow
         for impl in ["cpython", ""]:
             for version in range(11, 6, -1):
-                try:
+                with suppress(Exception):
                     # create a virtual environment which is also guaranteed to contain a recent enough pip (bundled)
                     session = cli_run(
                         [
@@ -42,12 +44,11 @@ def zipapp_build_env(tmp_path_factory):
                     exe = str(session.creator.exe)
                     found = True
                     break
-                except Exception:
-                    pass
             if found:
                 break
         else:
-            raise RuntimeError("could not find a python to build zipapp")
+            msg = "could not find a python to build zipapp"
+            raise RuntimeError(msg)
         cmd = [str(Path(exe).parent / "pip"), "install", "pip>=23", "packaging>=23"]
         subprocess.check_call(cmd)
     yield exe
@@ -75,18 +76,36 @@ def zipapp_test_env(tmp_path_factory):
 
 
 @pytest.fixture()
-def call_zipapp(zipapp, tmp_path, zipapp_test_env, temp_app_data):  # noqa: U100
+def call_zipapp(zipapp, tmp_path, zipapp_test_env, temp_app_data):  # noqa: ARG001
     def _run(*args):
-        cmd = [str(zipapp_test_env), str(zipapp), "-vv", str(tmp_path / "env")] + list(args)
+        cmd = [str(zipapp_test_env), str(zipapp), "-vv", str(tmp_path / "env"), *list(args)]
         subprocess.check_call(cmd)
 
     return _run
 
 
+@pytest.fixture()
+def call_zipapp_symlink(zipapp, tmp_path, zipapp_test_env, temp_app_data):  # noqa: ARG001
+    def _run(*args):
+        symlinked = zipapp.parent / "symlinked_virtualenv.pyz"
+        symlinked.symlink_to(str(zipapp))
+        cmd = [str(zipapp_test_env), str(symlinked), "-vv", str(tmp_path / "env"), *list(args)]
+        subprocess.check_call(cmd)
+
+    return _run
+
+
+@pytest.mark.skipif(not fs_supports_symlink(), reason="symlink not supported")
+def test_zipapp_in_symlink(capsys, call_zipapp_symlink):
+    call_zipapp_symlink("--reset-app-data")
+    _out, err = capsys.readouterr()
+    assert not err
+
+
 @flaky(max_runs=2, min_passes=1)
 def test_zipapp_help(call_zipapp, capsys):
     call_zipapp("-h")
-    out, err = capsys.readouterr()
+    _out, err = capsys.readouterr()
     assert not err
 
 
